ZoConnectivityController class
Constructors
- ZoConnectivityController()
-
factory
Properties
-
activeModes
→ List<
ConnectionMode> -
no setter
-
contextKey
→ GlobalKey<
NavigatorState> -
no setter
- currentContext ↔ BuildContext?
-
getter/setter pair
- currentMode → ConnectionMode
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAlertActive ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConnectionMode(
) → Future< ConnectionMode> - Directly queries the network hardware interfaces and returns the active ConnectionMode.
-
getConnectivityStatus(
) → Future< bool> -
hideNoInternetScreen(
) → Future< bool> -
isInternetBack(
{required dynamic internetStatus(bool)}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyOnline(
) → void -
setUp(
{Duration? checkInterval, Duration? timeout}) → Future< void> -
setupConnectivityListner(
{CustomNoInternetWrapper? offlineWidget, NoConnectivityStyle? connectivityStyle = NoConnectivityStyle.SNACKBAR, Widget? customAlert}) → Future< void> -
showNoInternet(
) → void -
showPlatformAlert(
) → void -
showSnackBar(
BuildContext context) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mapResult(
ConnectivityResult result) → ConnectionMode -
resolveModes(
List< ConnectivityResult> results) → ConnectionResolution