ZoPingService class

Properties

hashCode int
The hash code for this object.
no setterinherited
pingStream Stream<int>
Returns a stream of ping latencies in milliseconds.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
init({String? targetIp, int? targetPort, Duration? interval, Duration? timeout}) → void
Initialize the ping service with custom settings. If not called, defaults to pinging Google DNS (8.8.8.8:443) every 2 seconds.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZoPingService
final