ZoConnectivityWrapper class

Inheritance

Constructors

ZoConnectivityWrapper({Key? key, required ConnectionBuilder builder, GlobalKey<NavigatorState>? navigationKey, CustomNoInternetWrapper? offlineWidget, Widget? customAlert, NoConnectivityStyle? connectivityStyle = NoConnectivityStyle.SNACKBAR, void onConnectivityChanged(ConnectivityWatcherStatus status, ConnectionMode mode)?, void onConnectionModeChanged(ConnectionMode mode)?})
const

Properties

builder ConnectionBuilder
final
connectivityStyle NoConnectivityStyle?
Connection Style for the Wrapper : Default to snackbar
final
customAlert Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
If you already have the navigator key you can pass it here. If not passed, the package will assign its own key.
final
offlineWidget CustomNoInternetWrapper?
No internet widget that is to be shown
final
onConnectionModeChanged → void Function(ConnectionMode mode)?
Optional callback invoked when the connection mode changes (e.g. Wi-Fi to Mobile)
final
onConnectivityChanged → void Function(ConnectivityWatcherStatus status, ConnectionMode mode)?
Optional callback invoked when connectivity status or connection mode changes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ZoConnectivityWrapper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited