onConnectionModeChanged property
Optional callback invoked when the connection mode changes (e.g. Wi-Fi to Mobile)
Implementation
final void Function(ConnectionMode mode)? onConnectionModeChanged;
Optional callback invoked when the connection mode changes (e.g. Wi-Fi to Mobile)
final void Function(ConnectionMode mode)? onConnectionModeChanged;