StealthInternetChecker class
Constructors
-
StealthInternetChecker({Duration checkInterval = const Duration(seconds: 2), Duration timeout = const Duration(seconds: 2), int failureThreshold = 2, List<
String> ? hosts, List<Uri> ? endpoints, InternetAddress? target, int port = 53})
Properties
- checkInterval ↔ Duration
-
getter/setter pair
- failureThreshold → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastStatus → bool
-
no setter
-
lookupHosts
↔ List<
String> -
getter/setter pair
-
onStatusChange
→ Stream<
bool> -
no setter
-
probeEndpoints
↔ List<
Uri> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ Duration
-
getter/setter pair
Methods
-
dispose(
) → void -
getCurrentStatus(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyOffline(
) → void - Externally notify that hardware is disconnected (e.g. Airplane Mode / No SIM / Wi-Fi off).
-
notifyOnline(
) → void - Externally notify that network is confirmed working (e.g. from successful HTTP responses).
-
toString(
) → String -
A string representation of this object.
inherited
-
triggerCheck(
) → Future< void> - Triggers an immediate connectivity check out-of-band (e.g. when network interface changes).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
defaultProbeEndpoints
→ List<
Uri> -
final
Constants
-
defaultLookupHosts
→ const List<
String>