ConnectionMode enum

Represents the network connection mode through which device reaches the network.

Inheritance
Available extensions

Values

wifi → const ConnectionMode
mobile → const ConnectionMode
ethernet → const ConnectionMode
bluetooth → const ConnectionMode
vpn → const ConnectionMode
satellite → const ConnectionMode
other → const ConnectionMode
none → const ConnectionMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isBluetooth bool
no setter
isConnected bool
no setter
isEthernet bool
no setter
isMobile bool
no setter
isOther bool
no setter
isSatellite bool
no setter
isVpn bool
no setter
isWifi bool
no setter
label String
no setter
name String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectionMode>
A constant List of the values in this enum, in order of their declaration.